@@ -1,3 +1,4 @@
+import sys
 from pathlib import Path
 from typing import Optional, Union
 
@@ -27,6 +28,14 @@ def register(isettings: InstanceSettings, usettings):
     insert_if_not_exists.storage(isettings.storage.root, isettings.storage.region)
 
 
+def import_schema_lamin_root_api():
+    # only touch lamindb if we're operating from lamindb
+    if "lamindb" in sys.modules:
+        import lamindb
+
+        lamindb.schema._import_schema()
+
+
 def persist_check_reload_schema(isettings: InstanceSettings):
     # check whether we're switching from sqlite to postgres or vice versa
     # if we do, we need to re-import the schema modules to account for differences
@@ -139,6 +148,7 @@ def init(
     else:
         message = load_from_isettings(isettings, migrate=_migrate)
 
+    import_schema_lamin_root_api()
     return message
 
 
