@@ -6,8 +6,8 @@ from lnhub_rest._init_instance import init_instance as init_instance_hub
 from lnhub_rest._load_instance import load_instance as load_instance_from_hub
 
 from ._settings import InstanceSettings, settings
-from ._settings_load import load_instance_settings
-from ._settings_store import instance_settings_file
+from .dev._settings_load import load_instance_settings
+from .dev._settings_store import instance_settings_file
 
 
 def load(
@@ -67,7 +67,7 @@ def load(
         init_instance_hub(
             owner=isettings.owner,
             name=isettings.name,
-            storage=str(isettings.storage.root),
+            storage=isettings.storage.root_as_str,
             db=isettings._db,
             schema=isettings._schema_str,
         )
@@ -101,17 +101,22 @@ def load_from_isettings(
     isettings: InstanceSettings,
     migrate: Optional[bool] = None,
 ):
-    from ._init_instance import persist_check_reload_schema, register
-    from ._migrate import check_migrate
-    from ._setup_knowledge import load_bionty_versions
+    from ._init_instance import (
+        import_schema_lamin_root_api,
+        persist_check_reload_schema,
+        register,
+    )
+    from ._migrate import check_deploy_migration
+    from .dev._setup_knowledge import load_bionty_versions
 
     logger.info(f"Loading instance: {isettings.owner}/{isettings.name}")
     persist_check_reload_schema(isettings)
-    message = check_migrate(
+    message = check_deploy_migration(
         usettings=settings.user, isettings=isettings, migrate_confirmed=migrate
     )
     if message == "migrate-failed":
         return message
     register(isettings, settings.user)
     load_bionty_versions(isettings)
+    import_schema_lamin_root_api()
     return message
